
extern int default_text_size;
extern int default_text_caps;
extern gchar *default_print_command;
extern int default_net_direction_mode;
extern int default_net_selection_mode;
extern int default_zoom_with_pan;
extern int default_actionfeedback_mode;
extern int default_do_logging;
extern int default_embed_component;
extern int default_include_component;
extern int default_snap_size;

extern int default_scrollbars_flag;
extern gchar *default_print_paper;
extern int default_print_orientation;
extern int default_print_color;
extern int default_width;
extern int default_height;
extern int default_log_window;
extern int default_third_button;
extern int default_third_button_cancel;
extern int default_middle_button;
extern int default_scroll_wheel;
extern int default_file_preview;
extern int default_enforce_hierarchy;
extern int default_fast_mousepan;
extern int default_continue_component_place;
extern int default_undo_levels;
extern int default_undo_control;
extern int default_undo_type;
extern int default_undo_panzoom;
extern int default_draw_grips;
extern int default_netconn_rubberband;
extern int default_magnetic_net_mode;
extern int default_warp_cursor;
extern int default_toolbars;
extern int default_handleboxes;
extern int default_setpagedevice_orientation;
extern int default_setpagedevice_pagesize;
extern int default_bus_ripper_size;
extern int default_bus_ripper_type;
extern int default_bus_ripper_rotation;
extern int default_force_boundingbox;
extern int default_grid_mode;
extern int default_dots_grid_dot_size;
extern int default_dots_grid_mode;
extern int default_dots_grid_fixed_threshold;
extern int default_mesh_grid_display_threshold;
extern int default_auto_save_interval;
extern int default_mousepan_gain;
extern int default_keyboardpan_gain;
extern int default_select_slack_pixels;
extern int default_zoom_gain;
extern int default_scrollpan_steps;
extern gboolean default_tabs_enabled;
extern gboolean default_tabs_show_close_button;
extern gboolean default_tabs_show_up_button;
extern gboolean default_tabs_show_tooltips;
